@@ -253,54 +253,89 @@ sub _parse_sync_data {
                 #$msg->{content} = "收到[ " . $displayname  . " ]好友验证请求：" . ($verify?$verify:"(验证内容为空)");
                 $self->_webwxstatusnotify($e->{FromUserName},1);
                 $self->emit("friend_request",$id,$displayname,$verify,$ticket);
+                next;
+            }
+            elsif($e->{MsgType} == 10000){
+                $msg->{format} = "text";
+            }
+            elsif($e->{MsgType} == 49) {#应用分享
+                $msg->{format} = "app";
+                $msg->{app_title} = encode("utf8",$e->{FileName});
+                $msg->{app_url}   = encode("utf8",$e->{Url});
             }
             #elsif($e->{MsgType} == 51){#系统通知
             #    $msg->{format} = "text";
             #}
             else{next;}
-            if($e->{MsgType} == 1 or $e->{MsgType} == 3 or $e->{MsgType} == 34 or $e->{MsgType} == 62 or $e->{MsgType} == 47){
-                if(defined $msg->{content}){
-                    eval{
-                        $msg->{content} = Mojo::Util::html_unescape($msg->{content});
-                    };
-                    if($@){$self->warn("html entities unescape fail: $@")}
+            if($e->{FromUserName} eq $self->user->id){#发送的消息
+                $msg->{source} = 'outer';
+                $msg->{class} = "send";
+                $msg->{sender_id} = $self->user->id;
+                if($self->is_group($e->{ToUserName})){
+                    $msg->{type} = "group_message";
+                    $msg->{group_id} = $e->{ToUserName};
                 }
-                if($e->{FromUserName} eq $self->user->id){#发送的消息
-                    $msg->{source} = 'outer';
-                    $msg->{class} = "send";
-                    $msg->{sender_id} = $self->user->id;
-                    if($self->is_group($e->{ToUserName})){
-                        $msg->{type} = "group_message";
-                        $msg->{group_id} = $e->{ToUserName};
-                    }
-                    else{
-                        $msg->{type} = "friend_message";
-                        $msg->{receiver_id} = $e->{ToUserName};
-                    }
+                else{
+                    $msg->{type} = "friend_message";
+                    $msg->{receiver_id} = $e->{ToUserName};
                 }
-                elsif($e->{ToUserName} eq $self->user->id){#接收的消息
-                    $msg->{class} = "recv";
-                    $msg->{receiver_id} = $self->user->id;
-                    if($self->is_group($e->{FromUserName})){#接收到群组消息
-                        $msg->{type} = "group_message";
-                        $msg->{group_id} = $e->{FromUserName};
-                        my ($member_id,$content) = $msg->{content}=~/^(\@.+):<br\/>(.*)/g;
+            }
+            elsif($e->{ToUserName} eq $self->user->id){#接收的消息
+                $msg->{class} = "recv";
+                $msg->{receiver_id} = $self->user->id;
+                $msg->{type} = "group_message";
+                if($self->is_group($e->{FromUserName})){#接收到群组消息
+                    $msg->{group_id} = $e->{FromUserName};
+                    if($e->{MsgType} == 10000){#群提示信息
+                        $msg->{type} = "group_notice";
+                    }
+                    elsif( $msg->{content}=~/^(\@.+):<br\/>(.*)$/s ){
+                        my ($member_id,$content) = ($1,$2);
                         if(defined $member_id and defined $content){
                                 $msg->{sender_id} = $member_id;
                                 $msg->{content} = $content;
                         }
                     }
-                    else{
-                        $msg->{type} = "friend_message";
-                        $msg->{sender_id} = $e->{FromUserName};
-                    }
                 }
-                $msg->{content} = '[图片]' if $msg->{format} eq "media" and $msg->{media_type} eq "image";
-                $msg->{content} = '[语音]' if $msg->{format} eq "media" and $msg->{media_type} eq "voice";
-                $msg->{content} = '[视频]' if $msg->{format} eq "media" and $msg->{media_type} eq "video";
-                $msg->{content} = '[表情]' if $msg->{format} eq "media" and $msg->{media_type} eq "emoticon";
-                $self->message_queue->put(Mojo::Weixin::Message->new($msg)); 
+                else{#接收到的好友消息
+                    $msg->{type} = "friend_message";
+                    $msg->{sender_id} = $e->{FromUserName};
+                }
             }
+            if($msg->{format} eq "media"){
+                $msg->{content} = '[图片]' if $msg->{media_type} eq "image";
+                $msg->{content} = '[语音]' if $msg->{media_type} eq "voice";
+                $msg->{content} = '[视频]' if $msg->{media_type} eq "video";
+                $msg->{content} = '[表情]' if $msg->{media_type} eq "emoticon";
+            }
+            elsif(defined $msg->{content}){
+                eval{$msg->{content} = Mojo::Util::html_unescape($msg->{content});};
+                $self->warn("html entities unescape fail: $@") if $@;
+            }
+            if($msg->{format} eq "app"){
+                eval{
+                    $msg->{content}=~s/<br\/>/\n/g;
+                    require Mojo::DOM;
+                    my $dom = Mojo::DOM->new($msg->{content});
+                    $msg->{app_id} = $dom->at('msg > appmsg')->attr->{appid};
+                    $msg->{app_title} = $dom->at('msg > appmsg > title')->content;
+                    $msg->{app_desc} = $dom->at('msg > appmsg > des')->content;
+                    $msg->{app_url} = $dom->at('msg > appmsg > url')->content;
+                    $msg->{app_name} = $dom->at('msg > appinfo > appname')->content;
+                    for( ($msg->{app_title},$msg->{app_desc},$msg->{app_url},$msg->{app_name}) ){
+                        if($_=~/^<!\[CDATA\[.*\]\]>$/){
+                            s/^<!\[CDATA\[//g;
+                            s/\]\]>//g;
+                        }
+                    }
+                    $msg->{content} = "[应用分享]标题：@{[$msg->{app_title} || '未知']}\n[应用分享]描述：@{[$msg->{app_desc} || '未知']}\n[应用分享]应用：@{[$msg->{app_name} || '未知']}\n[应用分享]链接：@{[$msg->{app_url} || '未知']}";
+                };
+                if($@){
+                    $self->warn("app message xml parse fail: $@") if $@;
+                    $msg->{content} = "[应用分享]标题：$msg->{app_title}\n[应用分享]链接：$msg->{app_url}";
+                }
+            }
+            $self->message_queue->put(Mojo::Weixin::Message->new($msg)); 
         }
     }
 
