@@ -2,6 +2,7 @@ package Mojo::Weixin::Plugin::Openwx;
 our $PRIORITY = 98;
 use strict;
 use Encode;
+use Mojo::Util qw();
 use Mojo::Weixin::Server;
 my $server;
 sub call{
@@ -13,7 +14,7 @@ sub call{
     if(defined $post_api){
         $client->on(all_event => sub{
             my($client,$event,@args) =@_;
-            if($event eq  'login'){
+            if($event eq  'login' or $event eq 'stop'){
                 my $post_json = {};
                 $post_json->{post_type} = "event";
                 $post_json->{event} = $event;
@@ -28,6 +29,25 @@ sub call{
                     } 
                 });
             }
+            elsif($event eq 'input_qrcode'){
+                my ($qrcode_path,$qrcode_data) = @args;
+                eval{ $qrcode_data = Mojo::Util::b64_encode($qrcode_data);};
+                if($@){
+                    $client->warn("插件[".__PACKAGE__ . "]事件[".$event."]上报失败: $@");
+                    return;
+                }
+                my $post_json = {};
+                $post_json->{post_type} = "event";
+                $post_json->{event} = $event;
+                $post_json->{params} = [$qrcode_path,$qrcode_data];
+                my($data,$ua,$tx) = $client->http_post($post_api,json=>$post_json);
+                if($tx->success){
+                    $client->debug("插件[".__PACKAGE__ ."]事件[".$event . "]上报成功");
+                }
+                else{
+                    $client->warn("插件[".__PACKAGE__ . "]事件[".$event."]上报失败:" . encode("utf8",$tx->error->{message}));
+                }
+            }
             elsif($event =~ /^new_group|lose_group|new_friend|lose_friend|new_group_member|lose_group_member$/){
                 my $post_json = {};
                 $post_json->{post_type} = "event";
@@ -69,7 +89,7 @@ sub call{
         }) if $data->{post_event};
         $client->on(receive_message=>sub{
             my($client,$msg) = @_;
-            return if $msg->type !~ /^friend_message|group_message$/;
+            return if $msg->type !~ /^friend_message|group_message|group_notice$/;
             my $post_json = $msg->to_json_hash;
             delete $post_json->{media_data} if ($post_json->{format} eq "media" and ! $data->{post_media_data});
             $post_json->{post_type} = "receive_message";
