@@ -37,29 +37,43 @@ sub http_post{
     my $self = shift;
     return $self->_http_request("post",@_);
 }
+sub _ua_debug {
+    my ($self,$ua,$tx,$opt,$is_blocking) = @_;
+    return if not $opt->{ua_debug};
+    $self->print("-- " . ($is_blocking?"Blocking":"Non-blocking"). " request (@{[$tx->req->url->to_abs]})\n");
+
+    $opt->{ua_debug_req_body}?$self->print("-- Client >>> Server (@{[$tx->req->url->to_abs]})\n@{[$tx->req->to_string]}\n"):$self->print("-- Client >>> Server (@{[$tx->req->url->to_abs]})\n@{[$tx->req->build_start_line . $tx->req->build_headers]}\n[body data skipped]\n");
+
+    my $res_content_type = eval {$tx->res->headers->content_type};
+    if(defined $res_content_type and $res_content_type =~m#^(image|video|auido)/|^application/octet-stream#){
+        $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->build_start_line . $tx->res->build_headers]}\n[binary data not shown]");
+    }
+    else{
+        $opt->{ua_debug_res_body}?$self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n"):$self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->build_start_line . $tx->res->build_headers]}\n[body data skipped]\n");
+    }
+}
 sub _http_request{
     my $self = shift;
     my $method = shift;
-    my %opt = (json=>0,retry_times=>$self->ua_retry_times);
+    my %opt = (
+        json                =>  0,
+        retry_times         =>  $self->ua_retry_times,
+        ua_debug            =>  $self->ua_debug,
+        ua_debug_res_body   =>  $self->ua_debug_res_body,
+        ua_debug_req_body   =>  $self->ua_debug_req_body
+    );
     if(ref $_[1] eq "HASH"){#with header or option
         $opt{json} = delete $_[1]->{json} if defined $_[1]->{json};
         $opt{retry_times} = delete $_[1]->{retry_times} if defined $_[1]->{retry_times};
+        $opt{ua_debug}          = delete $_[1]->{ua_debug} if defined $_[1]->{ua_debug};
+        $opt{ua_debug_res_body} = delete $_[1]->{ua_debug_res_body} if defined $_[1]->{ua_debug_res_body};
+        $opt{ua_debug_req_body} = delete $_[1]->{ua_debug_req_body} if defined $_[1]->{ua_debug_req_body};
     }
     if(ref $_[-1] eq "CODE"){
         my $cb = pop;
-        $self->ua->$method(@_,sub{
+        return $self->ua->$method(@_,sub{
             my($ua,$tx) = @_;
-            if($self->ua_debug){
-                $self->print("-- Non-blocking request (@{[$tx->req->url->to_abs]})\n");
-                $self->print("-- Client >>> Server (@{[$tx->req->url->to_abs]})\n@{[$tx->req->to_string]}\n");
-                my $content_type = eval {$tx->res->headers->content_type};
-                if(defined $content_type and $content_type =~m#^image/|^application/octet-stream|^multipart/form-data#){
-                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->build_start_line . $tx->res->build_headers]}\n");
-                }
-                else{
-                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n");
-                }
-            }
+            _ua_debug($self,$ua,$tx,\%opt,0) if $opt{ua_debug};;
             $self->save_cookie();
             if(defined $tx and $tx->success){
                 my $r = $opt{json}?$self->decode_json($tx->res->body):$tx->res->body;
@@ -75,17 +89,7 @@ sub _http_request{
         my $tx;
         for(my $i=0;$i<=$opt{retry_times};$i++){
             $tx = $self->ua->$method(@_);
-            if($self->ua_debug){
-                $self->print("-- Blocking request (@{[$tx->req->url->to_abs]})\n");
-                $self->print("-- Client >>> Server (@{[$tx->req->url->to_abs]})\n@{[$tx->req->to_string]}\n");
-                my $content_type = eval {$tx->res->headers->content_type};
-                if(defined $content_type and $content_type =~m#^image/|^application/octet-stream#){
-                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->build_start_line . $tx->res->build_headers]}\n");
-                }
-                else{
-                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n");
-                }
-            }
+            _ua_debug($self,$ua,$tx,\%opt,1) if $opt{ua_debug};;
             $self->save_cookie();
             if(defined $tx and $tx->success){
                 my $r = $opt{json}?$self->decode_json($tx->res->body):$tx->res->body;
